@@ -18,7 +18,7 @@
 """
 Joblib spark backend is a extension for joblib, which make joblib running on spark parallelly.
 """
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 
 def register_spark():
@@ -31,7 +31,7 @@ def register_spark():
     except ImportError:
         msg = ("To use the spark.distributed backend you must install "
                "the pyspark and packages.\n\n")
-        raise ImportError(msg)
+        raise ImportError(msg)  # pylint: disable=raise-missing-from
 
 
 __all__ = ['register_spark']
